@@ -471,30 +471,31 @@ ALL_NUMBERS_S = f"{MIN_NUMBER}-{MAX_NUMBER}"
 # noinspection PyIncorrectDocstring
 def iip(items: Any = "", **kwargs) -> LInt:
     """Sorting IP protocol numbers and removing duplicates
-    :param items: Range of IP protocol numbers, can be unsorted and with duplicates,
-        "ip" - Return all IP protocol numbers: [0, 1, ..., 255]
-    :type items: str, List[int], List[str]
-
-    :param verbose: True - all protocol numbers in verbose mode: [0, 1, ..., 255],
-                    False - all protocol numbers in brief mode: [-1] to reduces RAM usage (default)
-    :type verbose: bool
-
-    :param strict: True - Raises ValueError, if the protocol is unknown (default)
-                   False - Skips unknown protocols
-
-    :param all: True - Return all IP protocol numbers: [0, 1, ..., 255]
-    :type all: bool
-
-    :return: *List[int]* of unique sorted IP protocol numbers
-    :rtype: List[int]
-
-    :raises ValueError: If IP protocol numbers are outside valid range 0...255
-
-    :example: Converts mix of ip protocol names and numbers to the numbers
-        iip("icmp,tcp,7,255") -> [1, 6, 7, 255]
-
-    :example: Converts ip to full range of ip protocol numbers
-        iip("ip") -> [0, 1, ... 254, 255]
+    ::
+        :param items: Range of IP protocol numbers, can be unsorted and with duplicates,
+            "ip" - Return all IP protocol numbers: [0, 1, ..., 255]
+        :type items: str, List[int], List[str]
+    
+        :param verbose: True - all protocol numbers in verbose mode: [0, 1, ..., 255],
+                        False - all protocol numbers in brief mode: [-1] to save RAM (default)
+        :type verbose: bool
+    
+        :param strict: True - Raises ValueError, if the protocol is unknown (default)
+                       False - Skips unknown protocols
+    
+        :param all: True - Return all IP protocol numbers: [0, 1, ..., 255]
+        :type all: bool
+    
+        :return: *List[int]* of unique sorted IP protocol numbers
+        :rtype: List[int]
+    
+        :raises ValueError: If IP protocol numbers are outside valid range 0...255
+    
+        :example: Converts mix of ip protocol names and numbers to the numbers
+            iip("icmp,tcp,7,255") -> [1, 6, 7, 255]
+    
+        :example: Converts ip to full range of ip protocol numbers
+            iip("ip") -> [0, 1, ... 254, 255]
     """
     if h.is_all(**kwargs):
         if h.is_brief(**kwargs):
@@ -530,28 +531,29 @@ def iip(items: Any = "", **kwargs) -> LInt:
 # noinspection PyIncorrectDocstring
 def sip(items: Any = "", **kwargs) -> str:
     """Soring string IP protocol numbers and removing duplicates
-    :param items: Range of IP protocol numbers, can be unsorted and with duplicates,
-        "ip" - mean all numbers in range 0...255
-    :type items: str, List[int], List[str]
-
-    :param verbose: True - all protocol numbers in verbose mode: [0, 1, ..., 255],
-                    False - all protocol numbers in brief mode: [-1], to reduces RAM usage (default)
-    :type verbose: bool
-
-    :param strict: True - Raises ValueError, if the protocol is unknown (default),
-                   False - Skips unknown protocols
-    :type strict: bool
-
-    :param all: True - Return all IP protocol numbers: "0-255"
-    :type all: bool
-
-    :return: *str* of unique sorted IP protocol numbers
-    :rtype: str
-
-    :raises ValueError: If IP protocol numbers are outside valid range 0...255
-
-    :example:
-        sip(["icmp", "tcp", "7", 255]) -> "1,6-7,255"
+    ::
+        :param items: Range of IP protocol numbers, can be unsorted and with duplicates,
+            "ip" - mean all numbers in range 0...255
+        :type items: str, List[int], List[str]
+    
+        :param verbose: True - all protocol numbers in verbose mode: [0, 1, ..., 255],
+                        False - all protocol numbers in brief mode: [-1], to save RAM (default)
+        :type verbose: bool
+    
+        :param strict: True - Raises ValueError, if the protocol is unknown (default),
+                       False - Skips unknown protocols
+        :type strict: bool
+    
+        :param all: True - Return all IP protocol numbers: "0-255"
+        :type all: bool
+    
+        :return: *str* of unique sorted IP protocol numbers
+        :rtype: str
+    
+        :raises ValueError: If IP protocol numbers are outside valid range 0...255
+    
+        :example:
+            sip(["icmp", "tcp", "7", 255]) -> "1,6-7,255"
     """
     if h.is_all(**kwargs):
         return ALL_NUMBERS_S
@@ -569,20 +571,21 @@ def sip(items: Any = "", **kwargs) -> str:
 # noinspection PyIncorrectDocstring
 def ip_pairs(items: Any, **kwargs) -> Tuple[LTIntStr, LStr]:
     """Splits items to IP protocol Number, Name and undefined-invalid protocols
-    :param items: Range of IP protocols, can be unsorted and with duplicates
-    :type items: str, List[int], List[str]
-
-    :param verbose: True - all protocol numbers in verbose mode: [0, 1, ..., 255],
-                    False - all protocol numbers in brief mode: [-1], to reduces RAM usage (default)
-    :type verbose: bool
-
-    :return: *List[Tuple[int, str]]* Pairs of IP protocol number and name,
-             *List[str]* Undefined protocol names and invalid numbers
-    :rtype: Tuple[List[Tuple[int, str]], List[str]]
-
-    :example:
-        ip_pairs("tcp,1,typo,256") -> [(1, "icmp"), (6, "tcp")], ["256", "typo"]
-        ip_pairs(["tcp", 1, "typo", 256]) -> [(1, "icmp"), (6, "tcp")], ["256", "typo"]
+    ::
+        :param items: Range of IP protocols, can be unsorted and with duplicates
+        :type items: str, List[int], List[str]
+    
+        :param verbose: True - all protocol numbers in verbose mode: [0, 1, ..., 255],
+                        False - all protocol numbers in brief mode: [-1], to save RAM (default)
+        :type verbose: bool
+    
+        :return: *List[Tuple[int, str]]* Pairs of IP protocol number and name,
+                 *List[str]* Undefined protocol names and invalid numbers
+        :rtype: Tuple[List[Tuple[int, str]], List[str]]
+    
+        :example:
+            ip_pairs("tcp,1,typo,256") -> [(1, "icmp"), (6, "tcp")], ["256", "typo"]
+            ip_pairs(["tcp", 1, "typo", 256]) -> [(1, "icmp"), (6, "tcp")], ["256", "typo"]
     """
     items_: LStr = [s.lower() for s in h.split(items)]
     if "ip" in items_:
@@ -631,8 +634,9 @@ def all_pairs():
 
 def _split_numbers_names(items: LStr) -> Tuple[SInt, SStr]:
     """Splits `items` to the numbers and names
-    :param items: Combo of numbers and names
-    :return: numbers, names
+    ::
+        :param items: Combo of numbers and names
+        :return: numbers, names
     """
     names: SStr = set()
     numbers: SInt = set()
@@ -647,8 +651,9 @@ def _split_numbers_names(items: LStr) -> Tuple[SInt, SStr]:
 
 def _split_names_undefined(items: SStr) -> Tuple[SStr, SStr]:
     """Splits `items` to the defined names and undefined names
-    :param items: Combo of defined names and undefined names
-    :return: defined names, undefined names
+    ::
+        :param items: Combo of defined names and undefined names
+        :return: defined names, undefined names
     """
     names: SStr = set()
     undefined: SStr = set()
@@ -665,8 +670,9 @@ def _split_names_undefined(items: SStr) -> Tuple[SStr, SStr]:
 
 def _split_numbers_invalid(items: SInt) -> Tuple[SInt, SStr]:
     """Splits `items` to the valid protocol numbers and invalid numbers
-    :param items: Combo of valid and invalid numbers
-    :return: valid numbers, invalid numbers
+    ::
+        :param items: Combo of valid and invalid numbers
+        :return: valid numbers, invalid numbers
     """
     numbers: SInt = set()
     invalid: SInt = set()
